# Chapgpt-cli
Command-line interface for Chatgpt

## Usage

```shell
chat
```

## Installation

```shell
pip install chatgpt-cli
requires python version >= 3.9
```

Obtain [API token](https://beta.openai.com/account/api-keys)
